@@ -1,29 +1,17 @@
-import sphinx
+# fmt: off
+import os
 
+import sphinx
 # from docutils import nodes
 from pkg_resources import parse_version
-from sphinxcontrib.needs.api import (
-    add_dynamic_function,
-    add_extra_option,
-    add_need_type,
-)
+from sphinx_needs.api import add_dynamic_function, add_extra_option, add_need_type
 
 from sphinxcontrib.test_reports.directives.test_case import TestCase, TestCaseDirective
-from sphinxcontrib.test_reports.directives.test_file import TestFile, TestFileDirective
-from sphinxcontrib.test_reports.directives.test_report import (
-    TestReport,
-    TestReportDirective,
-)
-from sphinxcontrib.test_reports.directives.test_suite import (
-    TestSuite,
-    TestSuiteDirective,
-)
-
 from sphinxcontrib.test_reports.directives.test_env import EnvReport, EnvReportDirective
-from sphinxcontrib.test_reports.directives.test_results import (
-    TestResults,
-    TestResultsDirective,
-)
+from sphinxcontrib.test_reports.directives.test_file import TestFile, TestFileDirective
+from sphinxcontrib.test_reports.directives.test_report import TestReport, TestReportDirective
+from sphinxcontrib.test_reports.directives.test_results import TestResults, TestResultsDirective
+from sphinxcontrib.test_reports.directives.test_suite import TestSuite, TestSuiteDirective
 from sphinxcontrib.test_reports.environment import install_styles_static_files
 from sphinxcontrib.test_reports.functions import tr_link
 
@@ -33,8 +21,9 @@ if parse_version(sphinx_version) >= parse_version("1.6"):
 else:
     import logging
 
+# fmt: on
 
-VERSION = "0.3.6"
+VERSION = "1.0.0"
 
 
 def setup(app):
@@ -65,6 +54,12 @@ def setup(app):
         "html",
     )
 
+    # adds option for custom template
+    template_dir = os.path.join(
+        os.path.dirname(__file__), "directives/test_report_template.txt"
+    )
+    app.add_config_value("tr_report_template", template_dir, "html")
+
     # nodes
     app.add_node(TestResults)
     app.add_node(TestFile)
@@ -114,7 +109,8 @@ def sphinx_needs_update(app, *args):
 
     # Extra options
     # For details read
-    # https://sphinxcontrib-needs.readthedocs.io/en/latest/api.html#sphinxcontrib.needs.api.configuration.add_extra_option
+    # https://sphinx-needs.readthedocs.io/en/latest/api.html#sphinx_needs.api.configuration.add_extra_option
+
     add_extra_option(app, "file")
     add_extra_option(app, "suite")
     add_extra_option(app, "case")
@@ -134,12 +130,12 @@ def sphinx_needs_update(app, *args):
 
     # Extra dynamic functions
     # For details about usage read
-    # https://sphinxcontrib-needs.readthedocs.io/en/latest/api.html#sphinxcontrib.needs.api.configuration.add_dynamic_function
+    # https://sphinx-needs.readthedocs.io/en/latest/api.html#sphinx_needs.api.configuration.add_dynamic_function
     add_dynamic_function(app, tr_link)
 
     # Extra need types
     # For details about usage read
-    # https://sphinxcontrib-needs.readthedocs.io/en/latest/api.html#sphinxcontrib.needs.api.configuration.add_need_type
+    # https://sphinx-needs.readthedocs.io/en/latest/api.html#sphinx_needs.api.configuration.add_need_type
     add_need_type(app, *app.config.tr_file[1:])
     add_need_type(app, *app.config.tr_suite[1:])
     add_need_type(app, *app.config.tr_case[1:])
